# uninstall

Uninstallation script for the eric IDE and all eric related tools.

### Global Attributes

currDir
defaultMacAppBundleName
defaultMacAppBundlePath
progLanguages
progName
pyModDir
settingsNameGlobal
settingsNameOrganization

### Classes

None

### Functions

exit | Exit the uninstall script.
getConfigDir | Module function to get the name of the directory storing the config data.
getWinregEntry | Function to get an entry from the Windows Registry.
initGlobals | Set the values of globals that need more than a simple assignment.
main | The main function of the script.
removeConfigurationData | Remove the eric configuration directory.
removeDataDirectory | Remove the eric data directory.
removePluginDirectories | Remove the plug-in directories.
uninstallEric | Uninstall the eric files.
uninstallLinuxSpecifics | Uninstall Linux specific files.
uninstallMacAppBundle | Uninstall the macOS application bundle.
uninstallWindowsLinks | Clean up the Desktop and Start Menu entries for Windows.
usage | Display a usage message and exit.
windowsDesktopNames | Function to generate the link names for the Windows Desktop.
windowsProgramsEntry | Function to generate the name of the Start Menu top entry.
wrapperNames | Create the platform specific names for the wrapper script.

## exit

exit(rcode=0)

Exit the uninstall script.

rcode
  result code to report back (integer)

Up

## getConfigDir

getConfigDir()

Module function to get the name of the directory storing the config data.

Return:
  directory name of the config dir (string)

Up

## getWinregEntry

getWinregEntry(name, path)

Function to get an entry from the Windows Registry.

name (str)
  variable name
path (str)
  registry path of the variable

Return:
  value of requested registry variable

Return Type:
  any

Up

## initGlobals

initGlobals()

Set the values of globals that need more than a simple assignment.

Up

## main

main(argv)

The main function of the script.

argv
  list of command line arguments

Up

## removeConfigurationData

removeConfigurationData()

Remove the eric configuration directory.

Up

## removeDataDirectory

removeDataDirectory()

Remove the eric data directory.

Up

## removePluginDirectories

removePluginDirectories()

Remove the plug-in directories.

Up

## uninstallEric

uninstallEric()

Uninstall the eric files.

Up

## uninstallLinuxSpecifics

uninstallLinuxSpecifics()

Uninstall Linux specific files.

Up

## uninstallMacAppBundle

uninstallMacAppBundle()

Uninstall the macOS application bundle.

Up

## uninstallWindowsLinks

uninstallWindowsLinks()

Clean up the Desktop and Start Menu entries for Windows.

Up

## usage

usage(rcode=2)

Display a usage message and exit.

rcode
  return code passed back to the calling process (integer)

Up

## windowsDesktopNames

windowsDesktopNames()

Function to generate the link names for the Windows Desktop.

Return:
  list of desktop link names

Return Type:
  list of str

Up

## windowsProgramsEntry

windowsProgramsEntry()

Function to generate the name of the Start Menu top entry.

Return:
  name of the Start Menu top entry

Return Type:
  str

Up

## wrapperNames

wrapperNames(dname, wfile)

Create the platform specific names for the wrapper script.

dname
  name of the directory to place the wrapper into
wfile
  basename (without extension) of the wrapper script

Return:
  the names of the wrapper scripts

Up